package core.notevault.ui.gallery;

import android.os.AsyncTask;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import androidx.annotation.NonNull;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import com.google.android.material.floatingactionbutton.FloatingActionButton;
import core.notevault.R;
import core.notevault.data.Concert;
import core.notevault.data.MusicDatabase;
import core.notevault.data.MusicNote;
import core.notevault.data.MusicNoteDAO;
import core.notevault.databinding.FragmentGalleryBinding;
import core.notevault.ui.gallery.editor.ConcertEditorDialog;

import java.util.List;

public class GalleryFragment extends Fragment {

    private FragmentGalleryBinding binding;
    private ConcertAdapter concertAdapter;

    public View onCreateView(@NonNull LayoutInflater inflater,
                             ViewGroup container, Bundle savedInstanceState) {
        GalleryViewModel galleryViewModel =
                new ViewModelProvider(this).get(GalleryViewModel.class);

        binding = FragmentGalleryBinding.inflate(inflater, container, false);
        View root = binding.getRoot();

        RecyclerView recyclerView = root.findViewById(R.id.concert_recycler_view);
        concertAdapter = new ConcertAdapter();
        recyclerView.setAdapter(concertAdapter);
        recyclerView.setLayoutManager(new LinearLayoutManager(getContext()));

        new LoadConcerts().execute();
        FloatingActionButton addConcertBtn = root.findViewById(R.id.add_concert_btn);
        addConcertBtn.setOnClickListener(v -> onCreateNewConcert());
        return root;
    }

    private class LoadConcerts extends AsyncTask<Void, Void, List<Concert>> {

        @Override
        protected List<Concert> doInBackground(Void... voids) {
            MusicDatabase db = MusicDatabase.getDatabase(getContext());
            MusicNoteDAO musicNoteDAO = db.musicNoteDao();
            return musicNoteDAO.getAllConcerts();
        }

        @Override
        protected void onPostExecute(List<Concert> concerts) {
            concertAdapter.updateConcerts(concerts); // Aktualisiere den Adapter mit den Titeln
        }
    }

    public void onCreateNewConcert() {
        ConcertEditorDialog concertEditorDialog = new ConcertEditorDialog();
        concertEditorDialog.show(getParentFragmentManager(), ConcertEditorDialog.TAG);
    }

    @Override
    public void onDestroyView() {
        super.onDestroyView();
        binding = null;
    }
}